==> kpogre_1.6.2.orig.tar.gz: kpogre-1.6.2/kpogre/PropertyPages/kpglanguageproppage.h <==
//
// C++ Interface: kpglanguageproppage
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGLANGUAGEPROPPAGE_H
#define KPGLANGUAGEPROPPAGE_H

#include "kpglanguageproppagebase.h"

// include files for libpgxx 
#include <pqxx/util> 

// application specific includes
#include "kpgabstractpropertypage.h"
#include "../kpgaclitem.h"

class KPGLanguage;

/**
  * Language properties
  *
  * @author Lumir Vanek
  */
class KPGLanguagePropPage : public KPGLanguagePropPageBase, public KPGAbstractPropertyPage
{
	Q_OBJECT
public:
    KPGLanguagePropPage(QWidget *, KPGLanguage *);
    ~KPGLanguagePropPage();
	
	// Display properties of underlying database object
	virtual void displayProperties();
	
	// Return Result table for clipboard actions and export. 
	virtual QTable* tableResult() { return m_pTableProperties; }
	
    void setACL(const QString &);
	
protected:

    KPGLanguage *m_pLanguage;
    KPGAclItemList m_listOfAclItems;
        
protected slots:
    
	virtual void slotTablePropDblClicked(int, int, int, const QPoint &);	
		    
    virtual void slotAclListViewClicked(QListViewItem *, const QPoint &, int);
    virtual void slotUpdateACL();
    
	// Consumes request for context menu for property table
	virtual void slotTablePropContextMenuRequested(int, int, const QPoint &);
    
signals:
	void sigSearchObject(const pqxx::oid);
  	void sigRunWizard(const QString &); 
  	
  	// Emit request for context menu for property table
	void sigTablePropContextMenuRequested(int, int, const QPoint &);
};

#endif

==> kpogre_3.0.0.orig.tar.gz: kpogre-3.0.0/kpogre/PropertyPages/kpglanguageproppage.h <==
//
// C++ Interface: kpglanguageproppage
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGLANGUAGEPROPPAGE_H
#define KPGLANGUAGEPROPPAGE_H

#include "kpglanguageproppagebase.h"

// include files for libpgxx 
#include <pqxx/util> 

// application specific includes
#include "kpgabstractpropertypage.h"
#include "../kpgaclitem.h"

class KPGLanguage;

/**
  * Language properties
  *
  * @author Lumir Vanek
  */
class KPGLanguagePropPage : public KPGLanguagePropPageBase, public KPGAbstractPropertyPage
{
	Q_OBJECT
public:
    KPGLanguagePropPage(QWidget *, KPGLanguage *);
    ~KPGLanguagePropPage();
	
	// Display properties of underlying database object
	virtual void displayProperties();
	
	// Return Result table for clipboard actions and export. 
	virtual QTable* tableResult() { return m_pTableProperties; }
	
    void setACL(const QString &);
	
protected:

    KPGLanguage *m_pLanguage;
    KPGAclItemList m_listOfAclItems;
        
protected slots:
    
	virtual void slotTablePropDblClicked(int, int, int, const QPoint &);	
		    
    virtual void slotAclListViewClicked(QListViewItem *, const QPoint &, int);
    virtual void slotUpdateACL();
    
	// Consumes request for context menu for property table
	virtual void slotTablePropContextMenuRequested(int, int, const QPoint &);
    
signals:
	void sigSearchObject(pqxx::oid);
    
  	void sigRunWizard(const QString &); 
  	
  	// Emit request for context menu for property table
	void sigTablePropContextMenuRequested(int, int, const QPoint &);
};

#endif
